(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30674,       1149]*)
(*NotebookOutlinePosition[     31992,       1189]*)
(*  CellTagsIndexPosition[     31948,       1185]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    RowBox[{"\n", 
      StyleBox[\(LIE\ DERIVATIVES\),
        FontFamily->"Helvetica",
        FontSize->14,
        FontVariations->{"Underline"->True}]}]], "Input"],

Cell["\<\
(*A fresh Kernel should be opened to use this demonstration \
program, which can be stepped through 
manually, or executed all at once by Evaluate Initialization and then \
scrolled through.  Because it uses \"%\" to reference prior output, it will \
not execute properly with Evaluate Notebook.  Printing the notebook can serve \
as a reference for AVF operations and syntax. Running time: < 1/2 min.*)
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(<< AVF.m;\)\)], "Input",
  InitializationCell->True],

Cell["\<\

(*SETTING UP SOME SCALAR VARIABLES*)\
\>", "Input",
  FormatType->TextForm],

Cell[BoxData[
    \(makescalars[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Introducing non-exact 1-forms will be delayed to a later \
section.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Since the algebra elements are constants, they are not actively \
involved in Lie differentiation. All the operations below can be applied to \
general AVF's, but for illustration we use ordinary differential forms; i.e., \
the trivial default algebra.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mtx[]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*LIE DERIVATIVE OF AVFS*)\
\>", "Input"],

Cell[TextData[{
  "(*",
  StyleBox["Using a coordinate basis",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The current \"forms\" list and the first convenience vector,*) \
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(vec1\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The function, lie[vec, avf], calculates the Lie derivative of \
\"avf\" with respect to a vector \"vec\" using the expansion: lie[vec_ , avf_ \
] : = vec \[SmallCircle] d[avf] + da[vec \[SmallCircle] avf] .  On a function \
of the scalars, \"lie\" just gives the directional derivative,*)\
\>", "Input",\

  FontFamily->"Times"],

Cell[BoxData[
    \(lie[vec1, F[x, y, z]]\)], "Input",
  InitializationCell->True],

Cell["(*But the convenience vector components are constants,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[vec1]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and usually one wants a vector field. There are two ways to turn \
the components of  V into field variables: either write them explicitly as \
specified or unspecified functions of \"scalars\"; or add the components into \
\"scalars\" as new independent variables. The problem with the first approach \
arises from Mathematica's output notation for derivatives of unspecified \
multi-variable functions, which is lengthy and not very readable.*) \
\>", \
"Input",
  FontFamily->"Times"],

Cell["\<\
(*Consider the vector V having unspecified functional components \
dual to {dx,dy,dz}, operating on a general 2-form T,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V = {v1[x, y, z], v2[x, y, z], v3[x, y, z]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(T = 
      X[x, y, z] dy\[Wedge]dz + Y[x, y, z] dz\[Wedge]dx + 
        Z[x, y, z] dx\[Wedge]dy\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, T]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["Introducing coordinates with \"makecoords\"",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*Better output is provided in AVF by establishing a subset of \
\"scalars\" as \"coords\", using the \"makecoords[]\" command. More details \
about \"makecoords[]\" are given at the end of this Notebook. Any \
pre-existing members of \"scalars\" which are not designated as \"coords\" \
will have subscript partial derivative expansions defined for them using \
Format output, and these are added into the \"drules\", which are invoked \
automatically for Lie derivatives.*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Using this approach, the scalar field variables in V and T are \
written without functional dependence, and are added into \"scalars\" before \
defining \"coords\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[{
    \(V = {v1, v2, v3}\), "\n", 
    \(T = X\ dy\[Wedge]dz + Y\ dz\[Wedge]dx + Z\ dx\[Wedge]dy\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[Join[scalars, V, {X, Y, Z}]]\)], "Input",
  InitializationCell->True],

Cell["(*and then \"coords\" is established,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Now the same Lie derivative performed above is output in a more \
readable form:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(lie[V, T]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*To sort that into independent bases, the canonical order of the \
basis 2-forms (as they appear there) must be used. This gives about the \
simplest possible output for general vectors and forms.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Collect[%, {dy\[Wedge]dz, dx\[Wedge]dz, dx\[Wedge]dy}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Note that the current \"drules\" are never invoked automatically \
in exterior differentiation; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[{v1, Y, T}]\)], "Input",
  InitializationCell->True],

Cell["(*but they will be applied using da[],*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[{v1, Y, T}]\)], "Input",
  InitializationCell->True],

Cell["(*and are automatic for all vector contractions,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V\[SmallCircle]d[{v1, Y, T}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Any variable not in \"scalars\" can have the same formatting of \
partial derivatives by writing it as a function of the reserved variable \
\"depend\", which inserts the dependence on \"coords\",*) \
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(f = F[depend]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[f]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, f]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The operators \"d\" and \"lie\" must commute identically for an \
arbitrary vector field,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[lie[V, f]] - lie[V, d[f]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*but the initial d[] derivative in that statement does ",
  StyleBox["not",
    FontVariations->{"Underline"->True}],
  " invoke the \"drules\" required to give the correct result; i.e.,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(applydrules[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the identity should be written using da[] rather than d[]; \
for example, on the 2-form T,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[lie[V, T]] - lie[V, da[T]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Clearly, this technique may not be helpful when some vector \
components and some \"scalars\" are independent of some \"coords\". In such \
cases, it may be better to use the standard functional notation, although it \
might also be feasible to edit out any unwanted terms from the automatically \
constructed \"drules\", to use \"makedrules[]\" with the edited drules, and \
so preserve the brevity given by the Format notation.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*",
  StyleBox["Lie product of vectors",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*Since both d[] and \[SmallCircle] extend to arrays of AVFs, so \
does the lie[] function. And since a vector is represented as a list of \
scalar components, lie[] can be applied to vectors as well. Introduce a new \
vector W,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(W = {w1, w2, w3}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[Join[scalars, W]]\)], "Input",
  InitializationCell->True],

Cell["(*To avoid duplication of \"drules\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[{}]\)], "Input",
  InitializationCell->True],

Cell["(*and now again make \"coords\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, W]\)], "Input",
  InitializationCell->True],

Cell["(*but for the Lie product this must be anti-symmetrized,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(VW = lie[V, W] - lie[W, V]\)], "Input",
  InitializationCell->True],

Cell["(*The identity for Lie differentiation reads*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Expand[
      lie[VW, T] - \((lie[V, lie[W, T]] - lie[W, lie[V, T]])\)]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["Anholonomic forms",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*Coordinate and anholonomic basis forms can perfectly well be \
mixed together, but for the moment the scalar variables will be \
dropped,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeforms[{\[Omega]\_1, \[Omega]\_2, \[Omega]\_3}]\)], "Input",
  InitializationCell->True],

Cell["(*The first convenience vector is given a shorter name,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V = vec1\)], "Input",
  InitializationCell->True],

Cell["\<\
(*By default, the \"drules\" specify closed 1-forms, and \"lie\" \
invokes \"drules\" automatically to perform the vector contractions involved. \
Furthermore, the vector V is constant,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[V]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*so the resulting Lie derivative of the 2-form, Q , \
vanishes.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Q = \[Omega]\_1\[Wedge]\[Omega]\_2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, Q]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The anholonomic basis can be given the Maurer-Cartan structure \
relations:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(mcdrules = {d\[Omega]\_1 \[Rule] \[Omega]\_2\[Wedge]\[Omega]\_3, 
        d\[Omega]\_2 \[Rule] \(-\((\[Omega]\_1\[Wedge]\[Omega]\_3)\)\), 
        d\[Omega]\_3 \[Rule] \[Omega]\_1\[Wedge]\[Omega]\_2}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makedrules[mcdrules]\)], "Input",
  InitializationCell->True],

Cell["(*and checking closure,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[da[forms]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The vector V becomes a field by making its components into \
independent \"scalars\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[V]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and now the Lie derivative and commutation property are \
non-trivial.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(lie[V, Q]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[lie[V, Q]] - lie[V, da[Q]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*When new basis forms appear, as the ",
  Cell[BoxData[
      \(TraditionalForm\`dv1\_i\)]],
  " above, the convenience vectors will automatically expand to accommodate \
them,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec1\)], "Input",
  InitializationCell->True],

Cell["\<\
(*but these 3 new components, representing contractions on the \
derivatives of the original vector components, are not in \"scalars\" and so \
are constant.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(d[vec1]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Taking higher Lie derivatives following this approach would \
require expanding the vectors and scalars at each new level. That is \
possible, but it gets out of hand rather quickly. However, the \"makecoords\" \
command can be used here to prevent the expansion; e.g.,*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*If higher derivatives are to be calculated, it will be necessary \
to expand V just once to cover contractions on the coordinate basis used to \
expand all scalar variables, say {x,y,z}*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Since all other \"scalars\" will be expanded on the coordinate \
basis, only these first 6 members of \"forms\" need to have vector \
components, and these components must appear in the final \"scalars\" list,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V = vec1\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[V]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and now use \"makecoords\" to get a complete set of \"drules\".*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{x, y, z}]\)], "Input",
  InitializationCell->True],

Cell["(*The final lists:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["(*Repeating the same Lie derivative as calculated above,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(VQ = lie[V, Q]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[VQ] - lie[V, da[Q]]\)], "Input",
  InitializationCell->True],

Cell["(*and a second derivative can now be evaluated,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(lie[V, VQ]\)], "Input",
  InitializationCell->True],

Cell["(*The coordinates can mix in with the anholonomic forms;*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(S = 
      dx\[Wedge]\[Omega]\_1 + dy\[Wedge]\[Omega]\_2 + 
        dz\[Wedge]\[Omega]\_3\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(VS = lie[V, S]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[VS] - lie[V, da[S]]\)], "Input",
  InitializationCell->True],

Cell["(*lie[] will operate on any array of AVFs*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(M = {{\[Omega]\_1, \[Omega]\_2}, {d\[Omega]\_1, 
          d\[Omega]\_2}}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, M]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(da[lie[V, M]] - lie[V, da[M]]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "\n(*",
  StyleBox["Lie products and the Lie algebra of non-exact forms",
    FontVariations->{"Underline"->True}],
  "*)"
}], "Input",
  FontFamily->"Times"],

Cell["\<\
(*The \"dual\" basis vectors are given by the rows of the identity \
matrix, where \"fmdim\" is the length of the \"forms\" list. The duals to the \
exact 1-forms in \"dscalars\" must commute, so can be eliminated,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(forms\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(duals = IdentityMatrix[fmdim];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(mtx[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A list of the Lie derivatives of the \"forms\" list with respect \
to each of their 3 dual vectors:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(lf = Table[lie[duals[\([m]\)], forms], {m, fmdim}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*And next, a list of the anti-symmetrized derivatives of each of \
these with respect to the dual vectors; equivalent to the Lie derivative of \
\"forms\" with respect to the Lie brackets of the duals.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      lie[duals[\([m]\)], lf[\([n]\)]] - 
        lie[duals[\([n]\)], lf[\([m]\)]], {m, fmdim - 1}, {n, m + 1, 
        fmdim}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Comparing the two lists, which contain the same results up to \
signs and order, reveals the Lie algebra of \"drules\".*)\
\>", "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*The function \"liealgebra[]\" will return a list of the Lie brackets, \
L[ ",
  Cell[BoxData[
      \(TraditionalForm\`V\&m, V\&n\)]],
  "] , for the full set\nof vectors dual to the current \"forms\" list \
(excluding any exact basis forms in \"dscalars\"),\nusing the current \
\"drules\" which must be defined for all the non-exact \"forms\".*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(liealgebra[]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The variable \"brackets\" contains the same thing, but with the \
numerical overscripts replaced by the corresponding dual 1-forms, which need \
not be indexed or ordered in the same way.*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(brackets\)], "Input",
  InitializationCell->True],

Cell["\<\


(*MAKECOORDS - FORMAT COMMAND FOR COORDINATES AND PARTIAL DERIVATIVES*)\
\>", 
  "Input",
  FormatType->TextForm],

Cell["(*Making a new \"scalars\" list:*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[{u, v, w}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*A special new set of \"scalars\" (or a subset of the existing \
\"scalars\") can be designated as \"coords\" by the command:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{x, y}]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Any new symbols introduced will be included automatically in \
\"scalars\" and \"dscalars\", with \"coords\" moving to the front.*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(scalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Any pre-existing \"scalars\" which are not designated as \"coords\
\" will have subscript partial
derivative symbols defined for them using Format output. A set of replacement \
rules, \"topartials\", is automatically generated to expand the exterior \
derivatives of these scalars in any AVF as follows:*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(topartials\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and the set \"topartials\" is automatically included in \
\"drules\", so that,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(dscalars /. topartials\)], "Input",
  InitializationCell->True],

Cell["(*can also be accomplished by,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[scalars]\)], "Input",
  InitializationCell->True],

Cell["(*with appropriate closure of the second derivative.*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(da[%]\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  "(*These partial derivative expansions provide a more concise and readable \
notation for the output of\nsome AVF expressions. Note that \"topartials\" is \
defined only for \"scalars\" introduced ",
  StyleBox["before",
    FontVariations->{"Underline"->True}],
  " the\n\"makecoords\" command is executed, and the transformations are \
implemented only for second partials.\nFurthermore, the subscript symbols are \
not recognized as derivatives by Mathematica for input.*)"
}], "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "\n(*By using contraction with the vectors dual to the \"coords\" basis \
forms, a particular partial derivative of an AVF (expressed in terms of \
\"coords\") is selected by the operator ",
  Cell[BoxData[
      \(TraditionalForm\`D\_sub\)]],
  ", where \"sub\" can be either the coordinate symbol, or an integer giving \
the position of the coordinate in the \"coords\" list. This operator extends \
to arrays of AVFs as well. For instance,*)"
}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(D\_x[{u^3, \ Sin[v]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(D\_1[%]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(D\_y[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Because the D operator is generated by first taking an exterior \
derivative, it may not give the expected result on a differential form, \
especially an exact one,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(D\_x[u\ dv + v\ du]\)], "Input",
  InitializationCell->True],

Cell["\<\

(*The selection of independent coordinates and dependent scalars can be \
changed at any time. For example, interchanging roles,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{u, v, w}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars /. topartials\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The variable \"depend\" can be used to make any other variable \
into a function of \"coords\" with
a similar output representation for its first and second derivatives; e.g.,*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(G[depend]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[%]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*which is a bit easier to scan than standard Mathematica output;*)\
\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[{}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d[G[u, v, w]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*and considerably improves the looks of the spherical Laplacian \
derived in AVF_Demo.nb*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    RowBox[{"Lsph", "=", 
      FractionBox[
        RowBox[{\(\[Omega]\_1\[Wedge]\[Omega]\_2\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(Csc[\[Theta]]\^2\), " ", 
                RowBox[{
                  SuperscriptBox["\[Psi]", 
                    TagBox[\((0, 2)\),
                      Derivative],
                    MultilineFunction->None], "[", \(\[Theta], \[Phi]\), 
                  "]"}]}], "+", 
              RowBox[{\(Cot[\[Theta]]\), " ", 
                RowBox[{
                  SuperscriptBox["\[Psi]", 
                    TagBox[\((1, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(\[Theta], \[Phi]\), 
                  "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["\[Psi]", 
                  TagBox[\((2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(\[Theta], \[Phi]\), 
                "]"}]}], ")"}]}], \(R\^2\)]}]], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makecoords[{\[Theta], \[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Lsph\)], "Input",
  InitializationCell->True],

Cell["\<\

(*This format is especially useful for Lie differentiation when the vector \
components are
expressed as functions of \"coords\".*)\
\>", "Input",
  FontFamily->"Times"],

Cell["\<\
(*Recalling the curvature on the spheroid from AVF_Demo.nb,*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\[CapitalOmega]\_\[Theta]\[Phi] = \(-\(\(\((\(-1\) + 
                  k)\)\ Sin[\[Theta]]\ d\[Theta]\[Wedge]d\[Phi]\)\/\((1 - k\ \
Sin[\[Theta]]\^2)\)\^\(3/2\)\)\)\)], "Input",
  InitializationCell->True],

Cell["\<\
(*we want its Lie derivative in the coordinate basis, with respect \
to a vector, V*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V = {v\&\[Theta], v\&\[Phi]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makeforms[{}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[{\[Theta], \[Phi], v\&\[Theta], v\&\[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makecoords[{\[Theta], \[Phi]}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(lie[V, \[CapitalOmega]\_\[Theta]\[Phi]]\)], "Input",
  PageBreakAbove->False,
  InitializationCell->True],

Cell[BoxData[
    \(Simplify[%, Trig -> False]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(sph = % /. k -> 0\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    FormBox[
      RowBox[{"(*", " ", 
        RowBox[{
          RowBox[{
            RowBox[{"A", " ", 
              RowBox[{"vector", 
                StyleBox[
                  RowBox[{" ", 
                    StyleBox[" ",
                      FontSize->14]}]], "(", " ", 
                \(\(v\&\[Theta]\) \[PartialD]\_\(\[Theta]\ \)\(+\ v\&\[Phi]\) 
                  \[PartialD]\_\[Phi]\), ")"}], "  ", "making", " ", "these", 
              " ", "expressions", " ", "vanish", " ", "would", " ", "leave", 
              " ", \(\[CapitalOmega]\_\[Theta]\[Phi]\), " ", 
              \(unchanged.\nAn\), " ", "obvious", " ", "solution", " ", 
              "from", " ", "symmetry", " ", "in", " ", "both", " ", "cases", 
              " ", "is", " ", "the", " ", "Killing", " ", 
              RowBox[{"vector", ":", " ", 
                RowBox[{\(v\&\[Theta]\), 
                  FormBox["",
                    "TraditionalForm"]}]}]}], "=", " ", "0"}], " ", ",", " ", 
          
          RowBox[{
            RowBox[{\(v\&\[Phi]\), 
              FormBox["",
                "TraditionalForm"]}], "=", " ", "1."}]}], " ", "*)"}], 
      TraditionalForm]], "Input"],

Cell["\<\

(*The \"makecoords\" facility  can be useful also for Hamiltonian mechanics. \
For a simple example using canonical coordinates in two dimensions:*)\
\>", \
"Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(canonical = {p1, p2, q1, q2}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(makescalars[canonical]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(dscalars\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\[Omega] = p1\ dq1 + p2\ dq2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(d\[Omega] = d[\[Omega]]\)], "Input",
  InitializationCell->True],

Cell["(*A convenience vector,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec1\)], "Input",
  InitializationCell->True],

Cell["(*can be edited to adapt it,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V = {vp\_1, vp\_2, vq\_1, vq\_2}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(V\[SmallCircle]dscalars\)], "Input",
  InitializationCell->True],

Cell["\<\
(*Adding in the vector components and an arbitrary Hamiltonian \
function to \"scalars\",*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makescalars[Join[scalars, V, {H}]]\)], "Input",
  InitializationCell->True],

Cell["(*To avoid including previous \"drules\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makedrules[{}]\)], "Input",
  InitializationCell->True],

Cell["(*and now introduce \"coords\",*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(makecoords[canonical]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(drules\)], "Input",
  InitializationCell->True],

Cell["(*The Hamiltonian flow equations read,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(V\[SmallCircle]d\[Omega] + da[H]\)], "Input",
  InitializationCell->True],

Cell["(*and taking the independent components,*)", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(eqns = setzero[Coefficient[%, dscalars]]\)], "Input",
  InitializationCell->True],

Cell["\<\
(*The Hamiltonian for a pair of coupled oscillators could \
be,*)\
\>", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(explicit = {H -> 
          Function[{p1, p2, q1, q2}, \((\ p1\^2 + p2\^2)\)/\((2\ m)\) + 
              k\ \((q1 - L)\)\^2/2 + 
              k\ \((q2 + L)\)\^2/2 + \[Epsilon]/
                  2 \((q1 - q2)\)\^2]}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(eqns = eqns /. explicit\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(equilibrium = eqns /. Thread[V -> {0, 0, 0, 0}]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Flatten[Solve[%, canonical]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(timer[]\)], "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 832}, {0, 604}},
AutoGeneratedPackage->None,
WindowSize->{629, 574},
WindowMargins->{{4, Automatic}, {-1, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?moogl<H`Ue0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@g[OK0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 182, 5, 43, "Input"],
Cell[1890, 57, 452, 9, 92, "Input"],
Cell[2345, 68, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[2422, 72, 86, 4, 42, "Input"],
Cell[2511, 78, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[2597, 82, 119, 4, 28, "Input"],
Cell[2719, 88, 304, 6, 60, "Input"],
Cell[3026, 96, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3095, 100, 52, 3, 42, "Input"],
Cell[3150, 105, 147, 6, 28, "Input"],
Cell[3300, 113, 115, 4, 28, "Input"],
Cell[3418, 119, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[3487, 123, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[3555, 127, 340, 7, 60, "Input"],
Cell[3898, 136, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[3983, 140, 96, 1, 28, "Input"],
Cell[4082, 143, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[4153, 147, 499, 9, 92, "Input"],
Cell[4655, 158, 169, 4, 44, "Input"],
Cell[4827, 164, 104, 2, 27, "Input",
  InitializationCell->True],
Cell[4934, 168, 156, 4, 27, "Input",
  InitializationCell->True],
Cell[5093, 174, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[5166, 178, 168, 6, 44, "Input"],
Cell[5337, 186, 523, 9, 92, "Input"],
Cell[5863, 197, 216, 5, 44, "Input"],
Cell[6082, 204, 151, 3, 43, "Input",
  InitializationCell->True],
Cell[6236, 209, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[6340, 213, 79, 1, 28, "Input"],
Cell[6422, 216, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[6507, 220, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[6577, 224, 132, 4, 28, "Input"],
Cell[6712, 230, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[6785, 234, 247, 5, 44, "Input"],
Cell[7035, 241, 115, 2, 27, "Input",
  InitializationCell->True],
Cell[7153, 245, 153, 4, 28, "Input"],
Cell[7309, 251, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[7386, 255, 80, 1, 28, "Input"],
Cell[7469, 258, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[7547, 262, 90, 1, 28, "Input"],
Cell[7640, 265, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[7732, 269, 249, 5, 44, "Input"],
Cell[7984, 276, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[8061, 280, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[8129, 284, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[8202, 288, 141, 4, 28, "Input"],
Cell[8346, 294, 88, 2, 27, "Input",
  InitializationCell->True],
Cell[8437, 298, 245, 6, 44, "Input"],
Cell[8685, 306, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[8763, 310, 146, 4, 28, "Input"],
Cell[8912, 316, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[9005, 320, 481, 8, 92, "Input"],
Cell[9489, 330, 147, 6, 44, "Input"],
Cell[9639, 338, 278, 6, 60, "Input"],
Cell[9920, 346, 77, 2, 27, "Input",
  InitializationCell->True],
Cell[10000, 350, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[10093, 354, 79, 1, 28, "Input"],
Cell[10175, 357, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[10253, 361, 74, 1, 28, "Input"],
Cell[10330, 364, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[10415, 368, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[10485, 372, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[10558, 376, 98, 1, 28, "Input"],
Cell[10659, 379, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[10749, 383, 86, 1, 28, "Input"],
Cell[10838, 386, 132, 3, 27, "Input",
  InitializationCell->True],
Cell[10973, 391, 142, 6, 44, "Input"],
Cell[11118, 399, 189, 5, 44, "Input"],
Cell[11310, 406, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[11389, 410, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[11503, 414, 97, 1, 28, "Input"],
Cell[11603, 417, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[11675, 421, 235, 5, 44, "Input"],
Cell[11913, 428, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[11983, 432, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[12051, 436, 114, 4, 28, "Input"],
Cell[12168, 442, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[12266, 446, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[12339, 450, 127, 4, 28, "Input"],
Cell[12469, 456, 260, 4, 27, "Input",
  InitializationCell->True],
Cell[12732, 462, 81, 2, 27, "Input",
  InitializationCell->True],
Cell[12816, 466, 65, 1, 28, "Input"],
Cell[12884, 469, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[12961, 473, 137, 4, 28, "Input"],
Cell[13101, 479, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[13179, 483, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[13248, 487, 122, 4, 28, "Input"],
Cell[13373, 493, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[13446, 497, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[13539, 501, 235, 7, 44, "Input"],
Cell[13777, 510, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[13845, 514, 207, 5, 44, "Input"],
Cell[14055, 521, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[14126, 525, 321, 6, 60, "Input"],
Cell[14450, 533, 237, 5, 44, "Input"],
Cell[14690, 540, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[14776, 544, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[14845, 548, 263, 6, 44, "Input"],
Cell[15111, 556, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[15183, 560, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[15261, 564, 117, 4, 28, "Input"],
Cell[15381, 570, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[15466, 574, 60, 1, 28, "Input"],
Cell[15529, 577, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[15600, 581, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[15669, 585, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[15739, 589, 98, 1, 28, "Input"],
Cell[15840, 592, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[15918, 596, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[16004, 600, 89, 1, 28, "Input"],
Cell[16096, 603, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[16170, 607, 98, 1, 28, "Input"],
Cell[16271, 610, 150, 4, 27, "Input",
  InitializationCell->True],
Cell[16424, 616, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[16502, 620, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[16588, 624, 83, 1, 28, "Input"],
Cell[16674, 627, 134, 3, 27, "Input",
  InitializationCell->True],
Cell[16811, 632, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[16884, 636, 90, 2, 27, "Input",
  InitializationCell->True],
Cell[16977, 640, 176, 6, 44, "Input"],
Cell[17156, 648, 266, 6, 44, "Input"],
Cell[17425, 656, 76, 2, 27, "Input",
  InitializationCell->True],
Cell[17504, 660, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[17573, 664, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[17671, 668, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[17741, 672, 151, 4, 28, "Input"],
Cell[17895, 678, 111, 2, 27, "Input",
  InitializationCell->True],
Cell[18009, 682, 252, 5, 44, "Input"],
Cell[18264, 689, 195, 5, 43, "Input",
  InitializationCell->True],
Cell[18462, 696, 171, 4, 44, "Input"],
Cell[18636, 702, 407, 9, 81, "Input"],
Cell[19046, 713, 73, 2, 27, "Input",
  InitializationCell->True],
Cell[19122, 717, 239, 5, 44, "Input"],
Cell[19364, 724, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[19436, 728, 125, 6, 72, "Input"],
Cell[19564, 736, 74, 1, 28, "Input"],
Cell[19641, 739, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[19727, 743, 176, 4, 44, "Input"],
Cell[19906, 749, 79, 2, 27, "Input",
  InitializationCell->True],
Cell[19988, 753, 183, 5, 44, "Input"],
Cell[20174, 760, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[20245, 764, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[20317, 768, 356, 7, 60, "Input"],
Cell[20676, 777, 71, 2, 27, "Input",
  InitializationCell->True],
Cell[20750, 781, 130, 4, 28, "Input"],
Cell[20883, 787, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[20969, 791, 72, 1, 28, "Input"],
Cell[21044, 794, 72, 2, 27, "Input",
  InitializationCell->True],
Cell[21119, 798, 94, 1, 28, "Input"],
Cell[21216, 801, 66, 2, 27, "Input",
  InitializationCell->True],
Cell[21285, 805, 530, 10, 76, "Input"],
Cell[21818, 817, 499, 10, 92, "Input"],
Cell[22320, 829, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[22405, 833, 68, 2, 27, "Input",
  InitializationCell->True],
Cell[22476, 837, 68, 2, 28, "Input",
  InitializationCell->True],
Cell[22547, 841, 216, 5, 44, "Input"],
Cell[22766, 848, 80, 2, 27, "Input",
  InitializationCell->True],
Cell[22849, 852, 179, 5, 60, "Input"],
Cell[23031, 859, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[23116, 863, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[23188, 867, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[23274, 871, 229, 6, 44, "Input"],
Cell[23506, 879, 70, 2, 27, "Input",
  InitializationCell->True],
Cell[23579, 883, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[23647, 887, 117, 4, 28, "Input"],
Cell[23767, 893, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[23845, 897, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[23922, 901, 139, 4, 28, "Input"],
Cell[24064, 907, 1050, 26, 45, "Input",
  InitializationCell->True],
Cell[25117, 935, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[25211, 939, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[25279, 943, 180, 6, 60, "Input"],
Cell[25462, 951, 111, 4, 28, "Input"],
Cell[25576, 957, 226, 4, 45, "Input",
  InitializationCell->True],
Cell[25805, 963, 133, 4, 28, "Input"],
Cell[25941, 969, 89, 2, 35, "Input",
  InitializationCell->True],
Cell[26033, 973, 74, 2, 27, "Input",
  InitializationCell->True],
Cell[26110, 977, 116, 2, 35, "Input",
  InitializationCell->True],
Cell[26229, 981, 91, 2, 27, "Input",
  InitializationCell->True],
Cell[26323, 985, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[26393, 989, 125, 3, 27, "Input",
  PageBreakAbove->False,
  InitializationCell->True],
Cell[26521, 994, 87, 2, 27, "Input",
  InitializationCell->True],
Cell[26611, 998, 78, 2, 27, "Input",
  InitializationCell->True],
Cell[26692, 1002, 1195, 27, 63, "Input"],
Cell[27890, 1031, 199, 6, 60, "Input"],
Cell[28092, 1039, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[28184, 1043, 83, 2, 27, "Input",
  InitializationCell->True],
Cell[28270, 1047, 69, 2, 27, "Input",
  InitializationCell->True],
Cell[28342, 1051, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[28434, 1055, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[28521, 1059, 65, 1, 28, "Input"],
Cell[28589, 1062, 65, 2, 27, "Input",
  InitializationCell->True],
Cell[28657, 1066, 70, 1, 28, "Input"],
Cell[28730, 1069, 93, 2, 28, "Input",
  InitializationCell->True],
Cell[28826, 1073, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[28913, 1077, 139, 4, 28, "Input"],
Cell[29055, 1083, 95, 2, 27, "Input",
  InitializationCell->True],
Cell[29153, 1087, 83, 1, 28, "Input"],
Cell[29239, 1090, 75, 2, 27, "Input",
  InitializationCell->True],
Cell[29317, 1094, 73, 1, 28, "Input"],
Cell[29393, 1097, 82, 2, 27, "Input",
  InitializationCell->True],
Cell[29478, 1101, 67, 2, 27, "Input",
  InitializationCell->True],
Cell[29548, 1105, 80, 1, 28, "Input"],
Cell[29631, 1108, 93, 2, 27, "Input",
  InitializationCell->True],
Cell[29727, 1112, 82, 1, 28, "Input"],
Cell[29812, 1115, 101, 2, 27, "Input",
  InitializationCell->True],
Cell[29916, 1119, 113, 4, 28, "Input"],
Cell[30032, 1125, 277, 6, 66, "Input",
  InitializationCell->True],
Cell[30312, 1133, 84, 2, 27, "Input",
  InitializationCell->True],
Cell[30399, 1137, 108, 2, 27, "Input",
  InitializationCell->True],
Cell[30510, 1141, 89, 2, 27, "Input",
  InitializationCell->True],
Cell[30602, 1145, 68, 2, 27, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

